summaryrefslogtreecommitdiff
path: root/src/server
diff options
context:
space:
mode:
Diffstat (limited to 'src/server')
-rw-r--r--src/server/rz_config.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/server/rz_config.py b/src/server/rz_config.py
index 09409726..03012048 100644
--- a/src/server/rz_config.py
+++ b/src/server/rz_config.py
@@ -39,11 +39,12 @@ class RZ_Config(object):
# - root_path: path to server root - relative paths are converted to absolute
# default: current working dir
# - user_db_path: user_db path - relative paths are converted to absolute
# - template_d_relpath: root_path relative location of template dir
#
- cfg['root_path'] = os.getcwd()
+ cfg['root_path'] = '.'
cfg['user_db_path'] = './user_db.db'
- cfg['template_d_relpath'] = 'fragment.d/template.d'
+ cfg['fragment_d_path'] = '/static/fragment.d'
+ cfg['template_d_path'] = '/static/fragment.d/template.d'
# client configuration
cfg['optimized_main'] = False
@@ -39,11 +39,12 @@ class RZ_Config(object):
# default: current working dir
# - user_db_path: user_db path - relative paths are converted to absolute
- # - template_d_relpath: root_path relative location of template dir
+ # - template_d_path: root_path relative location of template dir
#